@@ -506,7 +506,7 @@ public class EcmaHelpSource : HelpSource {
 				return null;
 
 			XsltArgumentList args = new XsltArgumentList();
-			args.AddExtensionObject("monodoc://extensions", ExtObject);
+			args.AddExtensionObject("monodoc:///extensions", ExtObject);
 			args.AddParam("show", "", "masteroverview");
 			string s = Htmlize(new XPathDocument (summary), args);
 			return BuildHtml (css_ecma_code, s); 
@@ -827,7 +827,7 @@ public class EcmaHelpSource : HelpSource {
 				return null;
 
 			XsltArgumentList args = new XsltArgumentList();
-			args.AddExtensionObject("monodoc://extensions", ExtObject);
+			args.AddExtensionObject("monodoc:///extensions", ExtObject);
 			args.AddParam("show", "", "namespace");
 			args.AddParam("namespace", "", ns_name);
 			string s = Htmlize(new XPathDocument (summary), args);
@@ -924,7 +924,7 @@ public class EcmaHelpSource : HelpSource {
 
 		XsltArgumentList args = new XsltArgumentList();
 
-		args.AddExtensionObject("monodoc://extensions", ExtObject);
+		args.AddExtensionObject("monodoc:///extensions", ExtObject);
 		
 		if (rest == "") {
 			args.AddParam("show", "", "typeoverview");
@@ -993,7 +993,7 @@ public class EcmaHelpSource : HelpSource {
 	public override void RenderPreviewDocs (XmlNode newNode, XmlWriter writer)
 	{
 		XsltArgumentList args = new XsltArgumentList ();
-		args.AddExtensionObject ("monodoc://extensions", ExtObject);
+		args.AddExtensionObject ("monodoc:///extensions", ExtObject);
 		
 		Htmlize (newNode, args, writer);
 	}
@@ -1751,13 +1751,14 @@ public class EcmaUncompiledHelpSource : EcmaHelpSource {
 				has_types = true;
 				string typename = t.GetAttribute("Name").Replace("+", ".");
 				
-				string url = ns.GetAttribute("Name") + "." + t.GetAttribute("Name");
-				Node typenode = nsnode.CreateNode(typename, "T:" + url);				
-				Node typemembers = typenode.CreateNode("Members", "T:" + url + "/*");
-				
 				// Must load in each document to get the list of members...
 				XmlDocument typedoc = new XmlDocument();
 				typedoc.Load(Path.Combine(Path.Combine(basedir.FullName, ns.GetAttribute("Name")), t.GetAttribute("Name") + ".xml"));
+				string kind = EcmaDoc.GetTypeKind (typedoc);
+				
+				string url = ns.GetAttribute("Name") + "." + t.GetAttribute("Name");
+				Node typenode = nsnode.CreateNode(typename + " " + kind, "T:" + url);				
+				Node typemembers = typenode.CreateNode("Members", "T:" + url + "/*");
 				
 				Hashtable groups = new Hashtable();
 				Hashtable groups_count = new Hashtable();
@@ -1864,7 +1865,7 @@ public class EcmaUncompiledHelpSource : EcmaHelpSource {
 
 			//transform the recently created masteroverview.xml
 			XsltArgumentList args = new XsltArgumentList();
-			args.AddExtensionObject("monodoc://extensions", ExtObject);
+			args.AddExtensionObject("monodoc:///extensions", ExtObject);
 			args.AddParam("show", "", "masteroverview");
 			string s = EcmaHelpSource.Htmlize(new XPathDocument (reader), args);
 			return BuildHtml (css_ecma_code, s); 
