@@ -470,7 +470,7 @@ public class HelpSource {
 		ZipEntry entry = zip_file.GetEntry (id);
 		if (entry != null) {
 			Stream s = zip_file.GetInputStream (entry);
-			string url = "monodoc://" + SourceID + "@" + System.Web.HttpUtility.UrlEncode (id) + "@";
+			string url = "monodoc:///" + SourceID + "@" + System.Web.HttpUtility.UrlEncode (id) + "@";
 			return new XmlTextReader (url, s);
 		}
 		return null;
@@ -484,7 +484,7 @@ public class HelpSource {
 		ZipEntry entry = zip_file.GetEntry (id);
 		if (entry != null) {
 			Stream s = zip_file.GetInputStream (entry);
-			string url = "monodoc://" + SourceID + "@" + System.Web.HttpUtility.UrlEncode (id) + "@";
+			string url = "monodoc:///" + SourceID + "@" + System.Web.HttpUtility.UrlEncode (id) + "@";
 			XmlReader r = new XmlTextReader (url, s);
 			XmlDocument ret = new XmlDocument ();
 			ret.Load (r);
