@@ -22,6 +22,7 @@ public class Stub {
 	static Assembly[] assemblies;
 	
 	static bool nooverrides = true, delete = false, ignoremembers = false;
+	static bool pretty = false;
 	
 	static int additions = 0, deletions = 0;
 
@@ -58,6 +59,10 @@ public class Stub {
 
 		[Option("An XML documemntation {file} made by the /doc option of mcs/csc the contents of which will be imported.")]
 		public string importslashdoc;
+		
+		[Option("Indent the XML files nicely.")]
+		public bool pretty = false;
+		
 	}
 	
 	private static int n(object o) {
@@ -77,6 +82,7 @@ public class Stub {
 		delete = opts.delete;
 		ignoremembers = opts.ignoremembers;
 		name = opts.name;
+		pretty = opts.pretty;
 
 		try {
 			// PARSE BASIC OPTIONS AND LOAD THE ASSEMBLY TO DOCUMENT
@@ -227,6 +233,7 @@ public class Stub {
 		string typename2 = type.FullName.Substring(type.Namespace == "" ? 0 : type.Namespace.Length+1);
 
 		XmlDocument basefile = new XmlDocument();
+		if (!pretty) basefile.PreserveWhitespace = true;
 		string typefile = basepath + "/" + type.Namespace + "/" + typename2 + ".xml";
 		try {
 			basefile.Load(typefile);
@@ -250,6 +257,7 @@ public class Stub {
 		
 		foreach (System.IO.FileInfo file in new System.IO.DirectoryInfo(nspath).GetFiles("*.xml")) {
 			XmlDocument basefile = new XmlDocument();
+			if (!pretty) basefile.PreserveWhitespace = true;
 			string typefile = nspath + "/" + file.Name;
 			try {
 				basefile.Load(typefile);
@@ -307,7 +315,7 @@ public class Stub {
 	{
 		string indexfile = dest + "/index.xml";
 		XmlDocument index;
-		if (new System.IO.FileInfo(indexfile).Exists) {
+		if (System.IO.File.Exists(indexfile)) {
 			index = new XmlDocument();
 			index.Load(indexfile);
 
@@ -360,6 +368,7 @@ public class Stub {
 			if (file.Exists) {
 				// Update
 				XmlDocument basefile = new XmlDocument();
+				if (!pretty) basefile.PreserveWhitespace = true;
 				try {
 					basefile.Load(typefile);
 				} catch (Exception e) {
