@@ -116,8 +116,11 @@ public class Monodocs2HTML {
 				if (opts.onlytype != null && !(nsname + "." + typename).StartsWith(opts.onlytype))
 					continue;
 
+				string typefile = opts.source + "/" + nsname + "/" + typename + ".xml";
+				if (!File.Exists(typefile)) continue;
+
 				XmlDocument typexml = new XmlDocument();
-				typexml.Load(opts.source + "/" + nsname + "/" + typename + ".xml");
+				typexml.Load(typefile);
 				
 				Console.WriteLine(nsname + "." + typename);
 				
